@@ -186,12 +186,12 @@ repeat_stmt(#repeat_stmt{body=B0}=R, _, St0) ->
 %%  The block info includes anything from the test expressions even
 %%  though we keep them separate.
 
-if_stmt(#if_stmt{tests=Ts0,else=E0}=If, Loc, St0) ->
+if_stmt(#if_stmt{tests=Ts0,else_block=E0}=If, Loc, St0) ->
     {Ts1,Tused,Tfused,St1} = if_tests(Ts0, Loc, St0),
     {E1,Eused,Efused,St2} = do_block(E0, St1),
     Used = union(Tused, Eused),
     Fused = union(Tfused, Efused),
-    {If#if_stmt{tests=Ts1,else=E1},[],Used,Fused,St2}.
+    {If#if_stmt{tests=Ts1,else_block=E1},[],Used,Fused,St2}.
 
 if_tests([{E0,B0}|Ts0], Loc, St0) ->
     {E1,Eused,Efused,St1} = exp(E0, Loc, St0),
